/*
 *  matrix_2D.cpp
 *
 *  Author: M. Reza Mozaffari
 *  Physics Group, University of Qom
 *  Created on: Jan. 2021
 */

#include "matrix_2D.h"
#include "vector_2D.h"

void print(M2D p)
{
    //   printf("[\n");
    for(int i = 0; i < ndim; i++) {
        printf("[");
        for(int j = 0; j < (ndim - 1); j++)
            printf("%.6f ", p.x[i][j]);
        printf("%.6f]\n", p.x[i][ndim - 1]);
    }
    printf("\n");
    //   printf("]\n");
}

void copy(M2D p, M2D& q)
{
    for(int i = 0; i < ndim; i++)
        for(int j = 0; j < ndim; j++)
            q.x[i][j] = p.x[i][j];
}

M2D add(M2D p, M2D q)
{
    M2D s;
    for(int i = 0; i < ndim; i++)
        for(int j = 0; j < ndim; j++)
            s.x[i][j] = p.x[i][j] + q.x[i][j];

    return s;
}

M2D sub(M2D p, M2D q)
{
    M2D s;
    for(int i = 0; i < ndim; i++)
        for(int j = 0; j < ndim; j++)
            s.x[i][j] = p.x[i][j] - q.x[i][j];

    return s;
}

M2D scale(M2D p, double alpha)
{
    M2D s;
    for(int i = 0; i < ndim; i++)
        for(int j = 0; j < ndim; j++)
            s.x[i][j] = alpha * p.x[i][j];

    return s;
}

V2D multi(M2D p, V2D u)
{
    V2D v{};
    for(int i = 0; i < ndim; i++)
        for(int j = 0; j < ndim; j++)
            v.x[i] += p.x[i][j] * u.x[j];

    return v;
}

M2D multi(M2D p, M2D q)
{
    M2D s{};
    for(int i = 0; i < ndim; i++)
        for(int j = 0; j < ndim; j++)
            for(int k = 0; k < ndim; k++)
                s.x[i][j] += p.x[i][k] *q.x[k][j] ;

    return s;
}