/*
 *  vector_2D.cpp
 *
 *  Author: M. Reza Mozaffari
 *  Physics Group, University of Qom
 *  Created on: Jan. 2021
 */

#include "vector_2D.h"

void print(V2D u)
{
    printf("[");
    for(int i = 0; i < (ndim - 1); i++)
        printf("%.6f ", u.x[i]);
    printf("%.6f]\n", u.x[ndim - 1]);
}

void copy(V2D u, V2D& v)
{
    for(int i = 0; i < ndim; i++)
        v.x[i] = u.x[i];
}

V2D add(V2D u, V2D v)
{
    V2D w;
    for(int i = 0; i < ndim; i++)
        w.x[i] = u.x[i] + v.x[i];

    return w;
}

V2D sub(V2D u, V2D v)
{
    V2D w;
    for(int i = 0; i < ndim; i++)
        w.x[i] = u.x[i] - v.x[i];

    return w;
}

V2D scale(V2D u, double alpha)
{
    V2D w;
    for(int i = 0; i < ndim; i++)
        w.x[i] = alpha * u.x[i];

    return w;
}

double dot(V2D u, V2D v)
{
    double res{ 0.0 };
    for(int i = 0; i < ndim; i++)
        res += u.x[i] * v.x[i];

    return res;
}

double cross(V2D u, V2D v)
{
    double res{ 0.0 };
    res = u.x[0] * v.x[1] - u.x[1] * v.x[0];

    return res;
}

double norm(V2D u)
{
    return sqrt(dot(u, u));
}

V2D hat(V2D u)
{
    return scale(u, 1. / norm(u));
}